@@ -203,7 +203,6 @@ class QuickBooks(object):
 
         self.access_token = session.access_token
         self.access_token_secret = session.access_token_secret
-
         return session
 
     def disconnect_account(self):
@@ -215,6 +214,14 @@ class QuickBooks(object):
         result = self.make_request("GET", url)
         return result
 
+    def change_data_capture(self, entity_string, changed_since):
+        url = self.api_url + "/company/{0}/cdc".format(self.company_id)
+
+        params = {"entities": entity_string, "changedSince": changed_since}
+
+        result = self.make_request("GET", url, params=params)
+        return result
+
     def reconnect_account(self):
         """
         Reconnect current account by refreshing OAuth access tokens
@@ -255,7 +262,7 @@ class QuickBooks(object):
                 'Connection': 'close'
             })
 
-            binary_data = str(base64.b64encode(attachment.read()))
+            binary_data = str(base64.b64encode(attachment.read()).decode('ascii'))
 
             content_type = json.loads(request_body)['ContentType']
 
@@ -349,6 +356,12 @@ class QuickBooks(object):
 
         return result
 
+    def delete_object(self, qbbo, request_body, _file_path=None):
+        url = self.api_url + "/company/{0}/{1}".format(self.company_id, qbbo.lower())
+        result = self.make_request("POST", url, request_body, params={'operation': 'delete'}, file_path=_file_path)
+
+        return result
+
     def batch_operation(self, request_body):
         url = self.api_url + "/company/{0}/batch".format(self.company_id)
         results = self.make_request("POST", url, request_body)
